<?xml version="1.0" encoding="UTF-8"?>
<!--
***********************************************************************
** Produces a list of showtimes for WML-enabled devices.
********************************************************************-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:param name="city_id" select="'stl'"/>
	<xsl:param name="theater_id" select="'ofallon'"/>
	
	<xsl:output method="xml" 
	version="1.0" encoding="UTF-8" indent="yes"
	 doctype-public="-//WAPFORUM//DTD WML 1.1//EN" 
	 doctype-system="http://www.wapforum.org/DTD/wml_1.1.xml"/>

	<!--
	*********************************************************************
	** The main template; creates the deck and the movies card.
	******************************************************************-->	
	<xsl:template match="/movies">
		<wml>
			<!-- generate the WML template -->
			<template>
				<do type="prev" label="Back" name="common_prev">
					<prev/>
				</do>
			</template>
			
			<card id="movies" title="Movies">
				<!-- shadow the template in this card -->
				<do type="prev" name="common_prev">
					<noop/>
				</do>
				
				<!-- select the theater that matches the city_id and
				     theater_id stylesheet parameters -->
				<xsl:apply-templates 
					select="city[@id=$city_id]/theater[@id=$theater_id]"/>
			</card>
			
			<!-- generate more cards, one per movie -->
			<xsl:apply-templates 
					select="city[@id=$city_id]/theater[@id=$theater_id]/movie"
						mode="createCard"/>

		</wml>
	</xsl:template>

	<!--
	*********************************************************************
	** Show more information about a theater.
	******************************************************************-->	
	<xsl:template match="theater">
		<p>
			<big>
				<xsl:value-of select="name"/>
			</big>
		</p>
		<p>Select a movie:</p>
		<p>
			<xsl:apply-templates select="movie"/>
		</p>
		
		<p>
			<em>
				<a href="movieguide?action=theaters&amp;city={$city_id}">
				        Change theater...</a>
			</em>
		</p>
	</xsl:template>
	
	<!--
	*********************************************************************
	** Show more information about a movie in the main card.
	******************************************************************-->	
 	<xsl:template match="movie">
		<xsl:variable  name="curId" select="@ref"/>
		<!-- the hyperlink text is the shortName from the <moviedef> -->
		<a href="#{$curId}">
			<xsl:value-of select="/movies/moviedef[@id=$curId]/shortName"/>
		</a>
		<br/>
	</xsl:template>		

	<!--
	*********************************************************************
	** Create a card for a movie that lists showtimes.
	******************************************************************-->	
	<xsl:template match="movie" mode="createCard">
		<xsl:variable  name="curId" select="@ref"/>

		<card id="{$curId}" title="Showtimes">
			<p>
				<em>
					<xsl:value-of select="/movies/moviedef[@id=$curId]/longName"/>
				</em>
			</p>
			<p>
				<xsl:value-of select="times"/>
			</p>
		</card>
	</xsl:template>			
</xsl:stylesheet>
