<?xml version="1.0" encoding="UTF-8"?>
<!--
***********************************************************
** postMsg.xslt
**
** Creates the "Post New Message" XHTML page and the
** "Reply to Message" XHTML page.
***********************************************************
-->
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:import href="utils.xslt"/>
  <!-- pass the root directory as a parameter, thus
       allowing this stylesheet to refer to the CSS file -->
  <xsl:param name="rootDir" select="'../docroot/'"/>
  
  <xsl:output method="xml" version="1.0" encoding="UTF-8" 
    indent="yes" 
    doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" 
    doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

  <!-- ===== Global Variables ===== -->
  <xsl:variable name="global.subject" select="/postMsg/prefill/subject"/>
  <xsl:variable name="global.email" select="/postMsg/prefill/authorEmail"/>
  <xsl:variable name="global.message" select="/postMsg/prefill/message"/>
  
  <xsl:variable name="global.title">
    <xsl:choose>
      <xsl:when test="/postMsg/inResponseTo">
        <xsl:text>Reply to Message</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>Post New Message</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
    
  <!--
  **********************************************************
  ** Create the XHTML web page
  *******************************************************-->
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml">
      <head>
        <title><xsl:value-of select="$global.title"/></title>
        <link href="{$rootDir}forum.css"
            rel="stylesheet" type="text/css"/>
      </head>
      <body>
        <!-- show the page title and board name -->
        <div class="box1">
          <h1><xsl:value-of select="$global.title"/></h1>
          <div>
            <xsl:value-of select="postMsg/board/name"/>
          </div>
        </div>
        <xsl:apply-templates select="postMsg/inResponseTo"/>
        
        <div class="box2">
          <!-- optionally display error message -->
          <xsl:if test="postMsg/error/@code='ALL_FIELDS_REQUIRED'">
            <p class="error">All fields are required...</p>
          </xsl:if>
          
          <!-- Create an XHTML form. The user will provide
               the subject, and Email address, and 
               the message text -->
          <form method="post" action="postMsg">
            <div>
            <input type="hidden" name="boardID" 
                value="{postMsg/board/@id}"/>
            
            <!-- Determine the mode of operation -->
            <xsl:choose>
              <xsl:when test="/postMsg/inResponseTo">
                <input type="hidden" name="origMsgID" value="{postMsg/inResponseTo/@id}"/>
                <input type="hidden" name="mode" value="replyToMsg"/>
              </xsl:when>
              <xsl:otherwise>
                <input type="hidden" name="mode" value="postNewMsg"/>
              </xsl:otherwise>
            </xsl:choose>
            </div>
            
            <!-- Show the input fields in a table to
                 keep things aligned properly -->
            <table>
              <tr>
                <td>Subject:</td>
                <td>
                  <input type="text" name="msgSubject" 
                      value="{$global.subject}" size="60" maxlength="70"/>
                </td>
              </tr>
              <tr>
                <td nowrap="nowrap">Your Email:</td>
                <td>
                  <input type="text" name="authorEmail" 
                      value="{$global.email}" size="60" maxlength="70"/>
                </td>
              </tr>
              <tr valign="top">
                <td>Message:</td>
                <td>
                  <!-- xsl:text prevents the XSLT processor from collapsing to
                       <textarea/>, which caused problems with many browsers -->
                  <textarea name="msgText" wrap="hard" rows="12" 
                      cols="60"><xsl:value-of 
                      select="$global.message"/><xsl:text> </xsl:text></textarea>
                </td>
              </tr>
              <!-- The last table row contains a submit
                   and cancel button -->
              <tr>
                <td> </td>
                <td>
                  <input type="submit" name="submitBtn" value="Submit"/>
                  <input type="submit" name="cancelBtn" value="Cancel"/>
                </td>
              </tr>
            </table>
          </form>
        </div>
      </body>
    </html>
  </xsl:template>
  
  <!--
  **********************************************************
  ** Show the text: 'In Response to: Msg Subject'
  *******************************************************-->  
  <xsl:template match="inResponseTo">
    <div>
      In Response to:
      <span style="font-weight: bold;">
      <xsl:value-of select="subject"/>
      </span>
    </div>
  </xsl:template>
</xsl:stylesheet>
